==> webkit2gtk_2.18.6.orig.tar.xz: webkitgtk-2.18.6/Source/WebKit/WebProcess/InjectedBundle/API/gtk/DOM/WebKitDOMBlob.h <==
/*
 *  This file is part of the WebKit open source project.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 */

#if !defined(__WEBKITDOM_H_INSIDE__) && !defined(BUILDING_WEBKIT)
#error "Only <webkitdom/webkitdom.h> can be included directly."
#endif

#ifndef WebKitDOMBlob_h
#define WebKitDOMBlob_h

#include <glib-object.h>
#include <webkitdom/WebKitDOMObject.h>
#include <webkitdom/webkitdomdefines.h>

G_BEGIN_DECLS

#define WEBKIT_DOM_TYPE_BLOB            (webkit_dom_blob_get_type())
#define WEBKIT_DOM_BLOB(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), WEBKIT_DOM_TYPE_BLOB, WebKitDOMBlob))
#define WEBKIT_DOM_BLOB_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass),  WEBKIT_DOM_TYPE_BLOB, WebKitDOMBlobClass)
#define WEBKIT_DOM_IS_BLOB(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), WEBKIT_DOM_TYPE_BLOB))
#define WEBKIT_DOM_IS_BLOB_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass),  WEBKIT_DOM_TYPE_BLOB))
#define WEBKIT_DOM_BLOB_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj),  WEBKIT_DOM_TYPE_BLOB, WebKitDOMBlobClass))

struct _WebKitDOMBlob {
    WebKitDOMObject parent_instance;
};

struct _WebKitDOMBlobClass {
    WebKitDOMObjectClass parent_class;
};

WEBKIT_API GType
webkit_dom_blob_get_type(void);

/**
 * webkit_dom_blob_get_size:
 * @self: A #WebKitDOMBlob
 *
 * Returns: A #guint64
**/
WEBKIT_API guint64
webkit_dom_blob_get_size(WebKitDOMBlob* self);

G_END_DECLS

#endif /* WebKitDOMBlob_h */

==> webkit2gtk_2.48.5.orig.tar.xz: webkitgtk-2.48.5/Source/WebKit/WebProcess/InjectedBundle/API/gtk/DOM/WebKitDOMBlob.h <==
/*
 *  This file is part of the WebKit open source project.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 */

#if !defined(__WEBKITDOM_H_INSIDE__) && !defined(BUILDING_WEBKIT)
#error "Only <webkitdom/webkitdom.h> can be included directly."
#endif

#ifndef WebKitDOMBlob_h
#define WebKitDOMBlob_h

#include <glib-object.h>
#include <webkitdom/WebKitDOMObject.h>
#include <webkitdom/webkitdomdefines.h>

G_BEGIN_DECLS

#define WEBKIT_DOM_TYPE_BLOB            (webkit_dom_blob_get_type())
#define WEBKIT_DOM_BLOB(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), WEBKIT_DOM_TYPE_BLOB, WebKitDOMBlob))
#define WEBKIT_DOM_BLOB_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass),  WEBKIT_DOM_TYPE_BLOB, WebKitDOMBlobClass)
#define WEBKIT_DOM_IS_BLOB(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), WEBKIT_DOM_TYPE_BLOB))
#define WEBKIT_DOM_IS_BLOB_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass),  WEBKIT_DOM_TYPE_BLOB))
#define WEBKIT_DOM_BLOB_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj),  WEBKIT_DOM_TYPE_BLOB, WebKitDOMBlobClass))

struct _WebKitDOMBlob {
    WebKitDOMObject parent_instance;
};

struct _WebKitDOMBlobClass {
    WebKitDOMObjectClass parent_class;
};

WEBKIT_DEPRECATED GType
webkit_dom_blob_get_type(void);

/**
 * webkit_dom_blob_get_size:
 * @self: A #WebKitDOMBlob
 *
 * Returns: A #guint64
 *
 * Deprecated: 2.22: Use JavaScriptCore API instead
**/
WEBKIT_DEPRECATED guint64
webkit_dom_blob_get_size(WebKitDOMBlob* self);

G_END_DECLS

#endif /* WebKitDOMBlob_h */
